# visualgl v0.0.2 ![Badge](https://github.com/jbschwartz/visualgl/actions/workflows/ci.yml/badge.svg)
A Python library for visualizations with OpenGL.

**Note: This library is currently being factored out from the [robotpy](https://github.com/jbschwartz/robotpy) application and is still very experimental.**

## Installation

Install using `pip`:

```
python -m pip install visualgl
```

Install using `poetry`:

```
poetry add visualgl
```
